@@ -11,16 +11,32 @@
 #' @param mu0 mortality at start period of time.
 #' @param theta A displacement coefficient of the Gompertz function.
 #' @param ystart A vector with length equal to number of dimensions used, defines starting values of covariates.
-#' @param tstart A number that defines starting time (30 by default).
+#' Default ystart = 80.
+#' @param tstart Starting time (age). 
+#' Can be a number (30 by default) or a vector of two numbers: c(a, b) - in this case, starting value of time 
+#' is simulated via uniform(a,b) distribution.
 #' @param tend A number, defines final time (105 by default).
 #' @param dt A time step (1 by default).
+#' @param nobs A number, defines a number of observations (lines) for an individual, NULL by default.
 #' @return A table with simulated data.
 #' @examples
 #' library(stpm)
-#' data <- simdata_discr(N=100, ystart=80)
+#' data <- simdata_discr(N=100)
 #' head(data)
 #'
-simdata_discr <- function(N=100, a=-0.05, f1=80, Q=2e-8, f=80, b=5, mu0=1e-5, theta=0.08, ystart=80, tstart=30, tend=105, dt=1) {
+simdata_discr <- function(N=100, 
+                          a=-0.05, 
+                          f1=80, 
+                          Q=2e-8, 
+                          f=80, 
+                          b=5, 
+                          mu0=1e-5, 
+                          theta=0.08, 
+                          ystart=80, 
+                          tstart=30, 
+                          tend=105, 
+                          dt=1,
+                          nobs=NULL) {
   
   k <- length(ystart)
   
@@ -38,6 +54,10 @@ simdata_discr <- function(N=100, a=-0.05, f1=80, Q=2e-8, f=80, b=5, mu0=1e-5, th
     stop("\'y'\ must be a 1 x k vector")
   }
   
+  if(length(tstart) > 2) {
+    stop(paste("Incorrect tstart:", tstart))
+  }
+  
   # Re-calculating parameters:
   u_ <- matrix((f1 %*% (-1*a)), nrow=k, ncol=1)
   R_ <- matrix((diag(k) + a), nrow=k, ncol=k)
@@ -47,7 +67,7 @@ simdata_discr <- function(N=100, a=-0.05, f1=80, Q=2e-8, f=80, b=5, mu0=1e-5, th
   Q_ <- matrix(Q, nrow=k, ncol=k)
   theta_ <- theta
   ystart = matrix(ystart, nrow=k, ncol=1)
-  simulated = .Call("simdata_ND", N, u_, R_, Sigma_, mu0_, b_, Q_, theta_, tstart, ystart, tend, k, dt);
+  simulated = .Call("simdata_ND", N, u_, R_, Sigma_, mu0_, b_, Q_, theta_, tstart, ystart, tend, k, dt, nobs);
   
   data_names <- c()
   for(n in 1:k) {
